summaryrefslogtreecommitdiff
path: root/test/lib/ansible_test/_internal/ci/local.py
diff options
context:
space:
mode:
Diffstat (limited to 'test/lib/ansible_test/_internal/ci/local.py')
-rw-r--r--test/lib/ansible_test/_internal/ci/local.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/test/lib/ansible_test/_internal/ci/local.py b/test/lib/ansible_test/_internal/ci/local.py
index fef5435bb2..4b9ab13ef7 100644
--- a/test/lib/ansible_test/_internal/ci/local.py
+++ b/test/lib/ansible_test/_internal/ci/local.py
@@ -63,8 +63,8 @@ class Local(CIProvider):
return prefix
- def get_base_branch(self) -> str:
- """Return the base branch or an empty string."""
+ def get_base_commit(self, args: CommonConfig) -> str:
+ """Return the base commit or an empty string."""
return ''
def detect_changes(self, args: TestConfig) -> t.Optional[list[str]]: